@@ -5,8 +5,8 @@ dolbyio_rest_apis.streaming.stream
 This module contains the functions to work with the Stream APIs.
 """
 
+from dolbyio_rest_apis.core.urls import get_rts_url
 from dolbyio_rest_apis.streaming.internal.http_context import StreamingHttpContext
-from dolbyio_rest_apis.streaming.internal.urls import SAPI_URL
 
 async def stop(
         api_secret: str,
@@ -20,7 +20,7 @@ async def stop(
     async with StreamingHttpContext() as http_context:
         await http_context.requests_post(
             api_secret=api_secret,
-            url=f'{SAPI_URL}/api/stream/stop',
+            url=f'{get_rts_url()}/api/stream/stop',
             payload=payload,
         )
 
@@ -30,5 +30,5 @@ async def stop_all(
     async with StreamingHttpContext() as http_context:
         await http_context.requests_post(
             api_secret=api_secret,
-            url=f'{SAPI_URL}/api/stream/stop/all',
+            url=f'{get_rts_url()}/api/stream/stop/all',
         )
